#include "orbsvcs/CosEvent/CEC_Pulling_Strategy.h"

TAO_BEGIN_VERSIONED_NAMESPACE_DECL

TAO_CEC_Pulling_Strategy::~TAO_CEC_Pulling_Strategy ()
{
}

TAO_END_VERSIONED_NAMESPACE_DECL
